
----------------------------------------------------------------------------------------------------------------
--[[ 	GupPet_DataHandler_Loaded																				]]--
----------------------------------------------------------------------------------------------------------------
function GupPet_DataHandler_Loaded()
	
	-- Bring them to default state
	if not GupPet_SavedOptions then
		GupPet_DataHandler_SetSavedOptionsDefault();
	end
	
	if not GupPet_SavedData then 
		GupPet_SavedData = {} ;
		
		GupPet_DataHandler_SetLocationsDefault();
		GupPet_DataHandler_SetCompanionDefault();
	end
	
	--Update Current version
	GupPet_DataHandler_UpdateSavedOptions();

end


----------------------------------------------------------------------------------------------------------------
----------------------------------------------------------------------------------------------------------------
----------------------------------------------------------------------------------------------------------------
----------------------------------------------------------------------------------------------------------------

--------------------------------------------------------------------------------------------------------------
-- GupPet_DataHandler_SetSavedOptionsDefault																	--
--------------------------------------------------------------------------------------------------------------
function GupPet_DataHandler_SetSavedOptionsDefault()
	
	--GupPet_SavedOptions["Mode"] ----> Starter = No Location Settings  , Expert = Location Settings
	--GupPet_SavedOptions["Style"] ---> CheckBox , Slider

	GupPet_SavedOptions = { Debug = false , Mode = "Starter", Style = "CheckBox" , AutoDismount = false ,

		Version = { Current = 0 , Found = 0 },
		
		AutoCritter	= { Enabled = false, Delay = 2, City = true , Arena = true , BattleGround = true , Outside = true , Party = true , Raid = true , 
						DismissWhileMounted = false,  
						Resummon = { Enabled = false , Delay = 10 , CityOnly = true },
						PetOfTheDay = { Enabled = false , Month = 0 , Day = 0, Year = 0 , PetID = 0 }	
						}, 
		IngameButton = { RelativePoint = "CENTER" , xOffset = 0 , yOffset = 0, Scale = 1 , Show = true , Lock = false , Preview = true , MountButton = "Auto" , CritterButton = true, Alignment = "H", HideKeyBind = false, HideTooltip = false,
						 Icons = { 	Multi = "Interface\\Icons\\Ability_Mount_Mammoth_Black" , 
									Ground = "Interface\\Icons\\Ability_Mount_Mammoth_Black" , 
									Fly = "Interface\\Icons\\Ability_Mount_Drake_Bronze" , 
									Auto = "Interface\\Icons\\Ability_Mount_Drake_Azure" ,
									Aquatic = "Interface\\Icons\\INV_Box_PetCarrier_01" ,
									Critter = "Interface\\Icons\\INV_Box_PetCarrier_01" 
								}	
							}, 
		MinimapButton 	= { Show = false , Radius = 78 , Position = 355 , xOffset = 0 , yOffset = 0 , Lock = true , RelativePoint = ""  } ,
		PreviewFrame 	= { Speed = 1 , StartPos = 0  },
		
		Class = {} ;
	} ;
end

----------------------------------------------------------------------------------------------------------------
--[[ 	GupPet_DataHandler_UpdateSavedOptions																	]]--
----------------------------------------------------------------------------------------------------------------
function GupPet_DataHandler_UpdateSavedOptions()
	
	--Update Current version 
	GupPet_SavedOptions["Version"]["Current"] = tonumber( GetAddOnMetadata("GupPet", "Version")) ; 
	
end

----------------------------------------------------------------------------------------------------------------
----------------------------------------------------------------------------------------------------------------
----------------------------------------------------------------------------------------------------------------
----------------------------------------------------------------------------------------------------------------

----------------------------------------------------------------------------------------------------------------
--[[ 	GupPet_DataHandler_SetCompanionDefault																]]--
----------------------------------------------------------------------------------------------------------------
function GupPet_DataHandler_SetCompanionDefault()
		
	GupPet_SavedData["Companion"] = { GroundMount={} , MultiMount={} , FlyMount = {} , AquaticMount = {} , UnknownMount= {} , Critter={} 	};
	
end

----------------------------------------------------------------------------------------------------------------
--[[ 	GupPet_DataHandler_UpdateAllCompanionWeight															]]--
----------------------------------------------------------------------------------------------------------------
function GupPet_DataHandler_UpdateAllCompanionWeights()

	local nrOffLocations = #GupPet_SavedData["Locations"] ;
	
	-- Process all the mounts
	local companionTypes = {"GroundMount" , "MultiMount" , "FlyMount" , "AquaticMount" , "UnknownMount" , "Critter" };
	
	for q = 1 , #companionTypes do
		
		if GupPet_SavedData["Companion"] == nil then return ; end
		if GupPet_SavedData["Companion"][ companionTypes[q] ] == nil then return; end
		
		local nrCompanions = #GupPet_SavedData["Companion"][ companionTypes[q] ] ;
	
		for w=1 , nrCompanions do
	
			-- Make a tempCopy of Weight
			local tmpWeight = {} ;
			
			for e=1 , nrOffLocations do
				
				if GupPet_SavedData["Companion"][ companionTypes[q] ][ w ]["Weight"][ GupPet_SavedData["Locations"][e]["ID"]  ] then
					tmpWeight[ GupPet_SavedData["Locations"][e]["ID"] ] =  GupPet_SavedData["Companion"][ companionTypes[q] ][ w ]["Weight"][  GupPet_SavedData["Locations"][e]["ID"]   ] ;
				else
					tmpWeight[   GupPet_SavedData["Locations"][e]["ID"]  ] = 0 ;
				end
			end
			
			GupPet_SavedData["Companion"][ companionTypes[q] ][ w ]["Weight"] = tmpWeight ;
			
		end
	end

end


----------------------------------------------------------------------------------------------------------------
--[[ 	GupPet_DataHandler_SetCompanionWeight																	]]--
----------------------------------------------------------------------------------------------------------------
function GupPet_DataHandler_SetCompanionWeight( companionType , companionIndex , locationID , weight  )

	if companionIndex == nil or companionIndex == 0 then
		local nrCompanions = #GupPet_SavedData["Companion"][companionType] ;
		
		for i=1 , nrCompanions do
			if ( GupPet_SavedData["Companion"][ companionType ][ i ]["Weight"][ locationID ] == 0 and weight > 0 ) or weight == 0 then
				GupPet_DataHandler_SetCompanionWeight( companionType , i , locationID , weight  );
			end
		end
		
		return;
	end
		
	GupPet_SavedData["Companion"][ companionType ][companionIndex]["Weight"][ locationID ] = weight ;

end

----------------------------------------------------------------------------------------------------------------
--[[ 	GupPet_DataHandler_UpdateCompanionWeight																]]--
----------------------------------------------------------------------------------------------------------------
function GupPet_DataHandler_UpdateCompanionWeight( compType , spellID , special  )
	
	local weight = {} ;
	local nrCompanions = #GupPet_SavedData["Companion"][compType] ;
	local companionIndex = -1 ;
	
	
	-- Get the companion Index by the spellID
	for i=1 , nrCompanions do
		if GupPet_SavedData["Companion"][compType][i]["SpellID"] == spellID then
			companionIndex = i ; 
			break ;
		end
	end

	
	-- Set the Weight for the Companion of the location IDs 
	
	local nrOffLocations = #GupPet_SavedData["Locations"] ;
	
	for i=1 , nrOffLocations do

		-- If the Weight is there replace it else to zero
		if GupPet_SavedData["Companion"][compType][companionIndex] then
			if GupPet_SavedData["Companion"][compType][companionIndex]["Weight"] then
				weight[ GupPet_SavedData["Locations"][i]["ID"]   ] = GupPet_SavedData["Companion"][compType][companionIndex]["Weight"][ GupPet_SavedData["Locations"][i]["ID"] ] or 0 ;
			else
				weight[ GupPet_SavedData["Locations"][i]["ID"]   ] = 0 ; 
			end
		else
			weight[ GupPet_SavedData["Locations"][i]["ID"]   ] = 0 ; 
		end
	
		-- If its a new mount .. companionIndex == -1 
		if companionIndex == -1 then
			--if GupPet_SavedData["Locations"][i]["Type"] == 0 and special ~= "Aq40" or GupPet_SavedData["Locations"][i]["Type"] == 21 and special == "Aq40" then
			if GupPet_SavedData["Locations"][i]["Type"] == 0 and special ~= "Aq40" then
				weight[ GupPet_SavedData["Locations"][i]["ID"]   ] = 1 ; 
			end
		end
	
	end

	return weight ;
	

end


----------------------------------------------------------------------------------------------------------------
--[[ 	GupPet_DataHandler_AddCompanion																		]]--
----------------------------------------------------------------------------------------------------------------
function GupPet_DataHandler_AddCompanion( creatureID, creatureName, creatureSpellID , slot , type , special )
	
	if special then
		return {  Name = creatureName , SpellID = creatureSpellID, CreatureID = creatureID ,Slot = slot , Weight = GupPet_DataHandler_UpdateCompanionWeight( type , creatureSpellID , special  ) , Special = special   } ;
	else
		return {  Name = creatureName , SpellID = creatureSpellID, CreatureID = creatureID ,Slot = slot , Weight = GupPet_DataHandler_UpdateCompanionWeight( type , creatureSpellID  )    } ;
	end
end


----------------------------------------------------------------------------------------------------------------
--[[ 	GupPet_DataHandler_UpdateCompanion																	]]--
----------------------------------------------------------------------------------------------------------------
function GupPet_DataHandler_UpdateCompanion( checkData )

	local GupPet_TempData = { GroundMount={} , MultiMount={} , FlyMount = {} , AquaticMount = {} , UnknownMount= {} , Critter={} 	};
	
	
	-- Grep the mount list
	for slot = 1, GetNumCompanions("MOUNT") do
		local creatureID, creatureName, creatureSpellID , creatureIcon = GetCompanionInfo("MOUNT", slot) ;
	
	
		if Gup_MountData[creatureSpellID] then
		
			-- Ground 
			if Gup_MountData[creatureSpellID][1] and Gup_MountData[creatureSpellID][2] then
				tinsert( GupPet_TempData["GroundMount"] , GupPet_DataHandler_AddCompanion( creatureID, creatureName, creatureSpellID , slot , "GroundMount" , "Aq40" )  );
			elseif Gup_MountData[creatureSpellID][1] then
				tinsert( GupPet_TempData["GroundMount"] , GupPet_DataHandler_AddCompanion( creatureID, creatureName, creatureSpellID , slot , "GroundMount" )  );
			end
			
			-- Fly
			if Gup_MountData[creatureSpellID][10] then
				tinsert( GupPet_TempData["FlyMount"] , GupPet_DataHandler_AddCompanion( creatureID, creatureName, creatureSpellID , slot , "FlyMount" )  );
			end
			
			-- Aquatic
			if Gup_MountData[creatureSpellID][20] and Gup_MountData[creatureSpellID][21]  then
				tinsert( GupPet_TempData["AquaticMount"] , GupPet_DataHandler_AddCompanion( creatureID, creatureName, creatureSpellID , slot , "AquaticMount" , "SeaLegs" )  );
			elseif Gup_MountData[creatureSpellID][20] then
				tinsert( GupPet_TempData["AquaticMount"] , GupPet_DataHandler_AddCompanion( creatureID, creatureName, creatureSpellID , slot , "AquaticMount" )  );
			end
			
			-- Multi
			if Gup_MountData[creatureSpellID][30] then
				tinsert( GupPet_TempData["MultiMount"] , GupPet_DataHandler_AddCompanion( creatureID, creatureName, creatureSpellID , slot , "MultiMount" )  );
			end
				
		else 
			-- Unknown
			tinsert( GupPet_TempData["UnknownMount"] , GupPet_DataHandler_AddCompanion( creatureID, creatureName, creatureSpellID , slot , "UnknownMount" )  );
		end
	
	
	end
	
	
	--Companions
	for slot = 1, GetNumCompanions("CRITTER") do
		local creatureID, creatureName, creatureSpellID = GetCompanionInfo("CRITTER", slot) ;
		
		if GupPet_CompanionData[creatureSpellID] then
		
			if GupPet_CompanionData[creatureSpellID][1] then
				tinsert( GupPet_TempData["Critter"] , GupPet_DataHandler_AddCompanion( creatureID, creatureName, creatureSpellID , slot , "Critter", "Snowball" )  );
			end
			
		else
			tinsert( GupPet_TempData["Critter"] , GupPet_DataHandler_AddCompanion( creatureID, creatureName, creatureSpellID , slot , "Critter" )  );
		end
		
	end 
	
	
	
	if #GupPet_TempData["UnknownMount"] > 0 then
		GupPet_Text( "|cffee4400".. GUPPET_L["UNKNOWNMOUNTFOUND"]   ) ;
	
		for i = 1 , #GupPet_TempData["UnknownMount"] do
			GupPet_Text( "|cffee4400 "..  GupPet_TempData["UnknownMount"][i]["Name"] .. " , "..  GupPet_TempData["UnknownMount"][i]["SpellID"] ) ;
		end
	end
	

	GupPet_SavedData["Companion"] = GupPet_TempData ;
	
	
	-- Check the Data if Mount/Comp are on Alfabeth .. If not wait for next event
	if checkData then
					
		local companionTypes = {"GroundMount" , "MultiMount" , "FlyMount" , "AquaticMount" , "UnknownMount" , "Critter" };
	
		for q = 1 , #companionTypes do
		
			for w = 1 , #GupPet_SavedData["Companion"][  companionTypes[q]   ]-1   do
		
				if GupPet_SavedData["Companion"][  companionTypes[q]   ][w]["Name"] >  GupPet_SavedData["Companion"][  companionTypes[q]   ][w+1]["Name"] then
					return false ;
					
				end
			end
		end
		return true;
	end
	
	return 
	
end

----------------------------------------------------------------------------------------------------------------
----------------------------------------------------------------------------------------------------------------
----------------------------------------------------------------------------------------------------------------
----------------------------------------------------------------------------------------------------------------

----------------------------------------------------------------------------------------------------------------
--[[ 	GupPetet_DataHandler_SetLocationsDefault																]]--
----------------------------------------------------------------------------------------------------------------
function GupPet_DataHandler_SetLocationsDefault()
	
	GupPet_SavedData["Locations"] = {
								{ Name = GUPPET_L["GLOBALWORLD"]   	, ID=1, Type = 0 , Enabled = true, UseFlyAsGround = false},
								{ Name = GUPPET_L["CITIES"]  			, ID=2, Type = 10, Enabled = true, UseFlyAsGround = false},
								{ Name = GUPPET_L["INSTANCES"] 		, ID=3, Type = 20, Enabled = true, UseFlyAsGround = false},
						--			{ Name = GUPPET_L["INSTANCE_AQ40"], ID=1, Type = 21, Enabled = true, UseFlyAsGround = false},
								{ Name = GUPPET_L["ARENAS"]  			, ID=4, Type = 30, Enabled = true, UseFlyAsGround = false},
								{ Name = GUPPET_L["BATTLEGROUNDS"] 	, ID=5, Type = 40, Enabled = true, UseFlyAsGround = false}
						};
	
	GupPet_DataHandler_LocationUpdated();
end

----------------------------------------------------------------------------------------------------------------
--[[ 	GupPet_DataHandler_AddLocation																		]]--
----------------------------------------------------------------------------------------------------------------
function GupPet_DataHandler_LocationUpdated()

	GupPet_DataHandler_UpdateAllCompanionWeights();
	
	-- Now some sorting
	table.sort(GupPet_SavedData["Locations"], 
					function(a,b)
						if a == nil then return nil ; end ;
						if b == nil then return nil ; end;
						
						if a["Type"] == b["Type"] then return a["Name"]<b["Name"] end 
						
						return a["Type"]< b["Type"] 
					end  
				);
end


----------------------------------------------------------------------------------------------------------------
--[[ 	GupPet_DataHandler_AddLocation																		]]--
----------------------------------------------------------------------------------------------------------------
function GupPet_DataHandler_AddLocation( zoneType , zoneName )

	-- Get some zone info first --
	if zoneType == nil then
		local _, instanceType = IsInInstance() ;
		zoneType = 0 ;
									
		if IsResting() then
			zoneType = 13
		elseif (   instanceType == "pvp" ) then
			zoneType = 43
		elseif (  instanceType == "arena" ) then
			zoneType = 33
		elseif  instanceType == "party" or instanceType == "raid"  then
			zoneType = 23
		else
			zoneType = 3
		end
	end
	
	if zoneName == nil then
		zoneName = GetRealZoneText()
	end
	
	-- First check if this zone is already here
	local nrOffLocations = #GupPet_SavedData["Locations"] ;
	local lastID = 0 ; 
	
	for i=1 , nrOffLocations do
	
		if GupPet_SavedData["Locations"][i]["Name"] == zoneName then
			return -1 ;  -- Error .. Location Already here
		end
		
		if GupPet_SavedData["Locations"][i]["ID"] > lastID then
			lastID = GupPet_SavedData["Locations"][i]["ID"] ;
		end
	
	end
	
	lastID = lastID+1 ; 
	
	-- Add it to the table
	tinsert(GupPet_SavedData["Locations"], 	{ Name = zoneName, ID= lastID, Type = zoneType, Enabled = true, UseFlyAsGround = false}	);
	
	GupPet_DataHandler_LocationUpdated();
	return 1 ; -- OK .. Location Added

end

----------------------------------------------------------------------------------------------------------------
--[[ 	GupPet_DataHandler_RemoveLocation																		]]--
----------------------------------------------------------------------------------------------------------------
function GupPet_DataHandler_RemoveLocation( zoneName )

	local nrOffLocations = #GupPet_SavedData["Locations"] ;

	for i=1 , nrOffLocations do
	
		-- Look for the Name
		if GupPet_SavedData["Locations"][i]["Name"] == zoneName then
		
			local zoneType = GupPet_SavedData["Locations"][i]["Type"] ;
		
			-- Check if its not a protected one
			if  zoneType == 3 or zoneType == 13 or zoneType == 23 or zoneType == 33 or zoneType == 43 then
		
				tremove(GupPet_SavedData["Locations"] , i ) ;
				GupPet_DataHandler_LocationUpdated();
				return 1 ;  -- OK
			else
				return -1 ; -- Error .... Protected
			end
		end
		
	end

	return -2 ; -- Error .

end

----------------------------------------------------------------------------------------------------------------
--[[ 	GupPet_DataHandler_UnlinkLocation																		]]--
----------------------------------------------------------------------------------------------------------------
function GupPet_DataHandler_UnlinkLocation( zoneName )

-- First check if this zone is already here
	local nrOffLocations = #GupPet_SavedData["Locations"] ;
	local lastID = 0 ; 
	local iZoneName =  0 ;
	
	for i=1 , nrOffLocations do
	
		if GupPet_SavedData["Locations"][i]["Name"] == zoneName then
			iZoneName = i ;
		end
		
		if GupPet_SavedData["Locations"][i]["ID"] > lastID then
			lastID = GupPet_SavedData["Locations"][i]["ID"] ;
		end
	
	end
	
	lastID = lastID+1 ; 
	
	GupPet_SavedData["Locations"][iZoneName]["ID"] = lastID ;
	
	GupPet_DataHandler_LocationUpdated();
end

----------------------------------------------------------------------------------------------------------------
--[[ 	GupPet_DataHandler_UnlinkLocationByIndex																]]--
----------------------------------------------------------------------------------------------------------------
function GupPet_DataHandler_UnlinkLocationByIndex( zoneIndex) 
-- First check if this zone is already here
	local nrOffLocations = #GupPet_SavedData["Locations"] ;
	local lastID = 0 ; 
		
	for i=1 , nrOffLocations do
	
		if GupPet_SavedData["Locations"][i]["ID"] > lastID then
			lastID = GupPet_SavedData["Locations"][i]["ID"] ;
		end
	
	end
	
	lastID = lastID+1 ; 
	
	GupPet_SavedData["Locations"][zoneIndex]["ID"] = lastID ;
	
	GupPet_DataHandler_LocationUpdated();
end

----------------------------------------------------------------------------------------------------------------
--[[ 	GupPet_DataHandler_LinkLocation																		]]--
----------------------------------------------------------------------------------------------------------------
function GupPet_DataHandler_LinkLocation( zoneName , toZoneName)

	--Find id and Link
	local iZoneName =  0 ;
	local toZoneID = 0 ;
	
	local nrOffLocations = #GupPet_SavedData["Locations"] ;

	for i=1 , nrOffLocations do
	
		if GupPet_SavedData["Locations"][i]["Name"] == zoneName then
			iZoneName = i ;
		end
		
		if GupPet_SavedData["Locations"][i]["Name"] == toZoneName then
			toZoneID = GupPet_SavedData["Locations"][i]["ID"] ;
		end
	
	end
	
	GupPet_SavedData["Locations"][iZoneName]["ID"] = toZoneID ;
	
	GupPet_DataHandler_LocationUpdated();
end

----------------------------------------------------------------------------------------------------------------
--[[ 	GupPet_DataHandler_LinkLocationByID																	]]--
----------------------------------------------------------------------------------------------------------------
function GupPet_DataHandler_LinkLocationByID( zoneID , toZoneID)

	--Find id and Link
	local iZoneName =  0 ;
	
	local nrOffLocations = #GupPet_SavedData["Locations"] ;

	for i=1 , nrOffLocations do
	
		if GupPet_SavedData["Locations"][i]["ID"] == zoneID then
			iZoneName = i ;
			break;
		end
		
	end
	
	GupPet_SavedData["Locations"][iZoneName]["ID"] = toZoneID ;
	
	GupPet_DataHandler_LocationUpdated();
end

----------------------------------------------------------------------------------------------------------------
--[[ 	GupPet_DataHandler_LinkLocationByIndex																]]--
----------------------------------------------------------------------------------------------------------------
function GupPet_DataHandler_LinkLocationByIndex( zoneIndex , toZoneIndex)

	GupPet_SavedData["Locations"][toZoneIndex]["ID"] = GupPet_SavedData["Locations"][zoneIndex]["ID"] ;
	
	GupPet_DataHandler_LocationUpdated();
end

----------------------------------------------------------------------------------------------------------------
--[[ 	GupPet_DataHandler_ToggleLinkLocationByIndex															]]--
----------------------------------------------------------------------------------------------------------------
function GupPet_DataHandler_ToggleLinkLocationByIndex( zoneIndex , toZoneIndex)
	
	-- You cant change the selected one.
	if zoneIndex == toZoneIndex then 
		return 
	end

	-- Check if already linked
	if GupPet_SavedData["Locations"][toZoneIndex]["ID"] == GupPet_SavedData["Locations"][zoneIndex]["ID"] then
		--Remove
		GupPet_DataHandler_UnlinkLocationByIndex( toZoneIndex) ;
	else
		--Set
		GupPet_DataHandler_LinkLocationByIndex( zoneIndex , toZoneIndex);
	end
	
end

----------------------------------------------------------------------------------------------------------------
--[[ 	GupPet_DataHandler_Location_SetUseFlyAsGround															]]--
----------------------------------------------------------------------------------------------------------------
function GupPet_DataHandler_Location_SetUseFlyAsGround( locationIndex , value )

	GupPet_SavedData["Locations"][locationIndex]["UseFlyAsGround"] = value ;
end

----------------------------------------------------------------------------------------------------------------
--[[ 	GupPet_DataHandler_Location_GetUserFlyAsGround														]]--
----------------------------------------------------------------------------------------------------------------
function GupPet_DataHandler_Location_GetUserFlyAsGround(locationIndex)
	return GupPet_SavedData["Locations"][locationIndex]["UseFlyAsGround"] == 1;
end

----------------------------------------------------------------------------------------------------------------
--[[ 	GupPet_DataHandler_Location_GetUserFlyAsGroundID														]]--
----------------------------------------------------------------------------------------------------------------
function GupPet_DataHandler_Location_GetUserFlyAsGroundID(locationID)
	local nrOffLocations = #GupPet_SavedData["Locations"] ;
	for i=1 , nrOffLocations do
		if GupPet_SavedData["Locations"][i]["ID"] then
			return GupPet_SavedData["Locations"][i]["UseFlyAsGround"] == 1 ;
		end
	end
end

----------------------------------------------------------------------------------------------------------------
--[[ 	GupPet_DataHandler_getLocationID																		]]--
----------------------------------------------------------------------------------------------------------------
function GupPet_DataHandler_getLocationID()

	local zoneName = GetRealZoneText() ;
	local nrOffLocations = #GupPet_SavedData["Locations"] ;

	local globalWorldID = 0 ;
	local citiesID = 0 ;
	local instanceID = 0 ;
	local arenaID = 0 ;
	local battleGroundID = 0 ;
	local zoneID = 0 ;
	
	for i=1 , nrOffLocations do
	
		if GupPet_SavedData["Locations"][i]["Name"] == zoneName then 
			zoneID = GupPet_SavedData["Locations"][i]["ID"] ;

		elseif GupPet_SavedData["Locations"][i]["Type"] == 0 then 
			globalWorldID = GupPet_SavedData["Locations"][i]["ID"] ;
		elseif GupPet_SavedData["Locations"][i]["Type"] == 10 then 
			citiesID = GupPet_SavedData["Locations"][i]["ID"] ;
		elseif GupPet_SavedData["Locations"][i]["Type"] == 20 then 
			instanceID = GupPet_SavedData["Locations"][i]["ID"] ;
		elseif GupPet_SavedData["Locations"][i]["Type"] == 30 then 
			arenaID = GupPet_SavedData["Locations"][i]["ID"] ;
		elseif GupPet_SavedData["Locations"][i]["Type"] == 40 then 
			battleGroundID = GupPet_SavedData["Locations"][i]["ID"] ;	
		end
	end
	
	return  zoneID , globalWorldID , citiesID , instanceID , arenaID , battleGroundID  ;
end
